@@ -31,12 +31,13 @@ _ascii_lowercase = "abcdef"
 _incorrect_lowercase = "ghijklmnopqrstuvwxyz"
 _digits = "0123456789"
 
-options = all_options = ["dataUri", "flip", "rotate", "scale", "radius", "size", "backgroundColor", "translateX",
-                         "translateY"]
-styles = ["adventurer", "adventurer-neutral", "avataaars", "big-ears", "big-ears-neutral",
-          "big-smile", "bottts", "croodles", "croodles-neutral", "identicon", "initials",
-          "micah", "miniavs", "open-peeps", "personas", "pixel-art", "pixel-art-neutral"]
-styles_depricated = ["female", "gridy", "human", "jdenticon", "male"]
+options = all_options = ["flip", "rotate", "scale", "radius", "size", "backgroundColor", "backgroundType",
+                         "backgroundRotation", "translateX", "translateY"]
+styles = ["adventurer", "adventurer-neutral", "avataaars", "avataaars-neutral", "big-ears", "big-ears-neutral",
+          "big-smile", "bottts", "bottts-neutral", "croodles", "croodles-neutral", "fun-emoji", "icons",
+          "identicon", "initials", "lorelei", "lorelei-neutral", "micah", "miniavs", "open-peeps", "personas",
+          "pixel-art", "pixel-art-neutral"]
+# styles_depricated = ["female", "gridy", "human", "jdenticon", "male"]
 
 
 class DColor:
@@ -44,30 +45,24 @@ class DColor:
     Base class for DAvatar's colors.
     """
 
-    def __init__(self, html_code: str = "#ffffff"):
+    def __init__(self, html_code: str = "transparent"):
         """
-        Colors used in this package. This uses HTML color codes!
+        Colors used in this package. This uses HTML/hex color codes!
 
-        :param html_code: class `str` :: the html color code to use as color (default: #ffffff)
+        :param html_code: class `str` :: the html color code to use as color (default: transparent)
         :type html_code: str
         :raise dicebear.errors.IncorrectColor:
         """
-        if html_code in ["random", "rnd"]:
-            html_code = '#' + ''.join(choices(_ascii_lowercase + _digits, k=6))
-        if not html_code.startswith("#"):
-            html_code = "#" + html_code
-        if len(html_code) not in [4, 7] or any(x in html_code for x in _incorrect_lowercase):
+        if html_code in ["random", "rnd"]: html_code = ''.join(choices(_ascii_lowercase + _digits, k=6))
+        if html_code.startswith("#"): html_code.replace("#", "")
+        if (len(html_code) != 6 or any(x in html_code for x in _incorrect_lowercase)) and html_code != "transparent":
             raise IncorrectColor(str(html_code))
         self.html_code: str = str(html_code)
 
-    def __str__(self):
-        return f"{self.html_code}"
-    def __repr__(self):
-        return f"{self.html_code}"
-    def __eq__(self, other):
-        return self.html_code == other.html_code
-    def __ne__(self, other):
-        return self.html_code != other.html_code
+    def __str__(self): return f"{self.html_code}"
+    def __repr__(self): return f"{self.html_code}"
+    def __eq__(self, other): return self.html_code == other.html_code
+    def __ne__(self, other): return self.html_code != other.html_code
 
     @staticmethod
     def random():
@@ -88,20 +83,26 @@ class DStyle:
     adventurer = styles[0]
     adventurer_neutral = styles[1]
     avataaars = styles[2]
-    big_ears = styles[3]
-    big_ears_neutral = styles[4]
-    big_smile = styles[5]
-    bottts = styles[6]
-    croodles = styles[7]
-    croodles_neutral = styles[8]
-    identicon = styles[9]
-    initials = styles[10]
-    micah = styles[11]
-    miniavs = styles[12]
-    open_peeps = styles[13]
-    personas = styles[14]
-    pixel_art = styles[15]
-    pixel_art_neutral = styles[16]
+    avataaars_neutral = styles[3]
+    big_ears = styles[4]
+    big_ears_neutral = styles[5]
+    big_smile = styles[6]
+    bottts = styles[7]
+    bottts_neutral = styles[8]
+    croodles = styles[9]
+    croodles_neutral = styles[10]
+    fun_emoji = styles[11]
+    icons = styles[12]
+    identicon = styles[13]
+    initials = styles[14]
+    lorelei = styles[15]
+    lorelei_neutral = styles[16]
+    micah = styles[17]
+    miniavs = styles[18]
+    open_peeps = styles[19]
+    personas = styles[20]
+    pixel_art = styles[21]
+    pixel_art_neutral = styles[22]
     def __init__(self):
         """Only use `.attribute` to use a style."""
         pass
@@ -127,9 +128,11 @@ class DFormat:
     All possible image formats for saving or converting avatars.
     - Note: Only works with attributes!
     """
-    list = all_formats = ["png", "svg"]
-    png = "png"
+    list = all_formats = ["svg", "png", "jpg", "json"]
     svg = "svg"
+    png = "png"
+    jpg = "jpg"
+    json = "json"
     def __init__(self):
         """Only use `.attribute` to use a format."""
         pass
@@ -143,9 +146,9 @@ class DFormat:
         """
         return eval("DFormat.{}".format(format_str.replace("DFormat.", "")))
 
-default_options: dict = {options[0]: False, options[1]: False, options[2]: 0, options[3]: 100, options[4]: 0,
-                         options[5]: 0, options[6]: DColor(), options[7]: 0, options[8]: 0}
 
+default_options: dict = {options[0]: False, options[1]: 0, options[2]: 100, options[3]: 0, options[4]: 0,
+                         options[5]: DColor(), options[6]: "solid", options[7]: 0, options[8]: 0, options[9]: 0}
 
 class DOptions(dict):
     """
@@ -153,34 +156,29 @@ class DOptions(dict):
     """
     empty: dict = {}
     default_options = default = default_options
-    def __init__(self, *, dataUri: bool = False, flip: bool = False, rotate: int = 0, scale: int = 100,
-                 radius: int = 0, size: int = 0, backgroundColor: DColor = DColor(), translateX: int = 0,
-                 translateY: int = 0, **kwargs):
+    def __init__(self, *, flip: bool = False, rotate: int = 0, scale: int = 100, radius: int = 0, size: int = 0,
+                 backgroundColor: DColor = DColor(), backgroundType: str = "solid", backgroundRotation: int = 0,
+                 translateX: int = 0, translateY: int = 0, **kwargs):
         """
         Go to https://github.com/jvherck/dicebear#base-options to see all info (important for minimum and maximum values for each option!)
 
         :param kwargs: `fromdict` to use a custom dict instead of args (if you use this kwarg all other args will be neglected)
         """
-        # kwargs: list = [dataUri, flip, rotate, scale, radius, size, backgroundColor, translateX, translateY]
         dic = kwargs.get("fromdict", {})
-        current: dict = {"dataUri": dataUri, "flip": flip, "rotate": rotate, "scale": scale, "radius": radius,
-                         "size": size,
-                         "backgroundColor": backgroundColor, "translateX": translateX, "translateY": translateY}
+        current: dict = {"flip": flip, "rotate": rotate, "scale": scale, "radius": radius, "size": size,
+                         "backgroundColor": backgroundColor, "backgroundType": backgroundType, "backgroundRotation": backgroundRotation,
+                         "translateX": translateX, "translateY": translateY}
         if dic:
             for item in dic:
-                if item not in default_options.keys() or dic[item] == default_options[item]:
-                    dic.pop(item, None)
+                if item not in default_options.keys() or dic[item] == default_options[item]: dic.pop(item, None)
         else:  # if not dic
             for item in current:
-                if item in default_options and current[item] != default_options[item]:
-                    dic.update({item: current[item]})
-        if "size" in dic and dic["size"] == 0:
-            dic.pop("size")
+                if item in default_options and current[item] != default_options[item]: dic.update({item: current[item]})
+        if "size" in dic and dic["size"] == 0: dic.pop("size")
         super().__init__(dic)
 
     @property
-    def _ver(self):
-        return type(self)
+    def _ver(self): return type(self)
 
 
 def pilcheck(func):
